@@ -1,6 +1,7 @@
-from .page import *
-from .inputs import *
-from .outputs import *
+from .generated.page import *
+from .generated.inputs import *
+from .generated.outputs import *
+from .generated.actions import *
 from .stdio import initialize as _initialize_stdio
 from .auth import *
 from .parameters import url_params
@@ -9,5 +10,5 @@ import os
 
 
 if os.environ.get("ENV") != "test":
-  _initialize_socket()
-  _initialize_stdio()
+    _initialize_socket()
+    _initialize_stdio()
