@@ -8,9 +8,10 @@ def writeWraper(type, write, text):
     send({"type": type, "log": text})
     return len(text)
 
+
 def initialize():
     stdout_write = sys.stdout.write
     stderr_write = sys.stderr.write
 
-    sys.stdout.write = lambda text: writeWraper('stdout', stdout_write, text)
-    sys.stderr.write = lambda text: writeWraper('stderr', stderr_write, text)
+    sys.stdout.write = lambda text: writeWraper("stdout", stdout_write, text)
+    sys.stderr.write = lambda text: writeWraper("stderr", stderr_write, text)
